# Green River near Jensen, UT (channel control)

## USGS Gage ID: 09261000

## Control
At the gage, the river is restricted to one channel at all stages.
The streambed is very flat and is composed of cobbles.
The banks consist of sand, gravel and cobbles.
Riparian vegetation includes sage brush, willows, greasewood, and tamarisk.
The left bank is not as steep as the right, which slopes up quite abruptly.
Both banks are quite stable and are not subject to overflow except at extremely high stages.
The channel is straight for several hundred yards upstream but bends sharply to the right about 2,000 feet below the station.
Channel control prevails at all but the lowest stages when a rocky riffle 200 feet below the gage becomes effective.
The riffle is quite stable. 

## Stage Ranges
- Reach control: < 3.70 ft
- Channel control: 3.70 to 14 ft